package bcn;


/** Represents a particular type of input intended to allow other behaviors
  * to influence the activation of the owner of this input port:
  * more than one output can be connected to this input port;
  * the magnitude of influence can't exceed the maximum;
  * the current value of influence should be checked at every control step;
  * every time the value is checked it is decreased a little, up to the minimum. */
public class InputInfluence implements InputPort<Float> {
    
	private final float min, max, dec;
    private float value;
    
    
    public InputInfluence(float min, float max, float dec) {
    	if (min > max) {
    		throw new IllegalArgumentException("The minimum level of influence allowed can't be greater than the maximum.");
    	}
        this.value = min;
        this.min = min;
        this.max = max;
        this.dec = dec;
    }
    
    
    @Override
    public synchronized Float get() {
    	float v = value;
    	value -= dec;
    	clip();
    	return v;
    }
    
    
    @Override
    public synchronized Float peek() {
        return get();
    }
    
    
    @Override
    public synchronized void put(Float influence) {
    	value += influence;
    	clip();
    }
    
    
    private void clip() {
    	if (value > max) {
    		value = max;
    	} else if (value < min) {
    		value = min;
    	}
    }
    
}
